@@ -1,8 +1,13 @@
-class ConfigError(Exception):
+class MyverError(Exception):
     """Configuration is invalid."""
     def __init__(self, message: str):
         self.message: str = message
         super().__init__()
 
-    def __str__(self):
-        return self.message
+
+class ConfigError(MyverError):
+    """Configuration is invalid."""
+
+
+class BumpError(MyverError):
+    """Bumping a version or part failed."""
